@@ -1,7 +1,7 @@
 import pytest
 import os
 
-from PyQt5.QtWidgets import QApplication
+from qtpy.QtWidgets import QApplication
 
 
 @pytest.fixture(scope="session", autouse=True)
