@@ -1,6 +1,7 @@
 import napari
 from napari.components.layerlist import LayerList
 from napari.layers import Layer
+from typing import List
 
 
 class ViewerAbstraction:
@@ -27,14 +28,18 @@ class ViewerAbstraction:
         """
         return self._viewer.layers
 
-    def get_active_layer(self) -> Layer:
+    def get_active_layer(self) -> List[Layer]:
         """
         Get the layer currently active (selected) in the Napari viewer
 
         inputs:
             viewer (Viewer): the Napari viewer
         """
-        return self._viewer.layers.selection.active
+        if self._viewer.layers.selection.active:
+            return [self._viewer.layers.selection.active]
+        else:
+            # two or more layers are selected, return all
+            return list(self._viewer.layers.selection._set)
 
     def add_image_layer(self, image_data, name: str) -> Layer:
         """
@@ -43,3 +48,9 @@ class ViewerAbstraction:
         :param: name: new layer name
         """
         return self._viewer.add_image(image_data, name=name)
+
+    def set_active_layer(self, layer: Layer):
+        self._viewer.layers.selection.active = layer
+
+    def get_theme(self):
+        return self._viewer.theme
